<?php

/** @generate-class-entries */

/**
 * @var int
 * @cvalue T_LNUMBER
 */
const T_LNUMBER = UNKNOWN;
/**
 * @var int
 * @cvalue T_DNUMBER
 */
const T_DNUMBER = UNKNOWN;
/**
 * @var int
 * @cvalue T_STRING
 */
const T_STRING = UNKNOWN;
/**
 * @var int
 * @cvalue T_NAME_FULLY_QUALIFIED
 */
const T_NAME_FULLY_QUALIFIED = UNKNOWN;
/**
 * @var int
 * @cvalue T_NAME_RELATIVE
 */
const T_NAME_RELATIVE = UNKNOWN;
/**
 * @var int
 * @cvalue T_NAME_QUALIFIED
 */
const T_NAME_QUALIFIED = UNKNOWN;
/**
 * @var int
 * @cvalue T_VARIABLE
 */
const T_VARIABLE = UNKNOWN;
/**
 * @var int
 * @cvalue T_INLINE_HTML
 */
const T_INLINE_HTML = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENCAPSED_AND_WHITESPACE
 */
const T_ENCAPSED_AND_WHITESPACE = UNKNOWN;
/**
 * @var int
 * @cvalue T_CONSTANT_ENCAPSED_STRING
 */
const T_CONSTANT_ENCAPSED_STRING = UNKNOWN;
/**
 * @var int
 * @cvalue T_STRING_VARNAME
 */
const T_STRING_VARNAME = UNKNOWN;
/**
 * @var int
 * @cvalue T_NUM_STRING
 */
const T_NUM_STRING = UNKNOWN;
/**
 * @var int
 * @cvalue T_INCLUDE
 */
const T_INCLUDE = UNKNOWN;
/**
 * @var int
 * @cvalue T_INCLUDE_ONCE
 */
const T_INCLUDE_ONCE = UNKNOWN;
/**
 * @var int
 * @cvalue T_EVAL
 */
const T_EVAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_REQUIRE
 */
const T_REQUIRE = UNKNOWN;
/**
 * @var int
 * @cvalue T_REQUIRE_ONCE
 */
const T_REQUIRE_ONCE = UNKNOWN;
/**
 * @var int
 * @cvalue T_LOGICAL_OR
 */
const T_LOGICAL_OR = UNKNOWN;
/**
 * @var int
 * @cvalue T_LOGICAL_XOR
 */
const T_LOGICAL_XOR = UNKNOWN;
/**
 * @var int
 * @cvalue T_LOGICAL_AND
 */
const T_LOGICAL_AND = UNKNOWN;
/**
 * @var int
 * @cvalue T_PRINT
 */
const T_PRINT = UNKNOWN;
/**
 * @var int
 * @cvalue T_YIELD
 */
const T_YIELD = UNKNOWN;
/**
 * @var int
 * @cvalue T_YIELD_FROM
 */
const T_YIELD_FROM = UNKNOWN;
/**
 * @var int
 * @cvalue T_INSTANCEOF
 */
const T_INSTANCEOF = UNKNOWN;
/**
 * @var int
 * @cvalue T_NEW
 */
const T_NEW = UNKNOWN;
/**
 * @var int
 * @cvalue T_CLONE
 */
const T_CLONE = UNKNOWN;
/**
 * @var int
 * @cvalue T_EXIT
 */
const T_EXIT = UNKNOWN;
/**
 * @var int
 * @cvalue T_IF
 */
const T_IF = UNKNOWN;
/**
 * @var int
 * @cvalue T_ELSEIF
 */
const T_ELSEIF = UNKNOWN;
/**
 * @var int
 * @cvalue T_ELSE
 */
const T_ELSE = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENDIF
 */
const T_ENDIF = UNKNOWN;
/**
 * @var int
 * @cvalue T_ECHO
 */
const T_ECHO = UNKNOWN;
/**
 * @var int
 * @cvalue T_DO
 */
const T_DO = UNKNOWN;
/**
 * @var int
 * @cvalue T_WHILE
 */
const T_WHILE = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENDWHILE
 */
const T_ENDWHILE = UNKNOWN;
/**
 * @var int
 * @cvalue T_FOR
 */
const T_FOR = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENDFOR
 */
const T_ENDFOR = UNKNOWN;
/**
 * @var int
 * @cvalue T_FOREACH
 */
const T_FOREACH = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENDFOREACH
 */
const T_ENDFOREACH = UNKNOWN;
/**
 * @var int
 * @cvalue T_DECLARE
 */
const T_DECLARE = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENDDECLARE
 */
const T_ENDDECLARE = UNKNOWN;
/**
 * @var int
 * @cvalue T_AS
 */
const T_AS = UNKNOWN;
/**
 * @var int
 * @cvalue T_SWITCH
 */
const T_SWITCH = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENDSWITCH
 */
const T_ENDSWITCH = UNKNOWN;
/**
 * @var int
 * @cvalue T_CASE
 */
const T_CASE = UNKNOWN;
/**
 * @var int
 * @cvalue T_DEFAULT
 */
const T_DEFAULT = UNKNOWN;
/**
 * @var int
 * @cvalue T_MATCH
 */
const T_MATCH = UNKNOWN;
/**
 * @var int
 * @cvalue T_BREAK
 */
const T_BREAK = UNKNOWN;
/**
 * @var int
 * @cvalue T_CONTINUE
 */
const T_CONTINUE = UNKNOWN;
/**
 * @var int
 * @cvalue T_GOTO
 */
const T_GOTO = UNKNOWN;
/**
 * @var int
 * @cvalue T_FUNCTION
 */
const T_FUNCTION = UNKNOWN;
/**
 * @var int
 * @cvalue T_FN
 */
const T_FN = UNKNOWN;
/**
 * @var int
 * @cvalue T_CONST
 */
const T_CONST = UNKNOWN;
/**
 * @var int
 * @cvalue T_RETURN
 */
const T_RETURN = UNKNOWN;
/**
 * @var int
 * @cvalue T_TRY
 */
const T_TRY = UNKNOWN;
/**
 * @var int
 * @cvalue T_CATCH
 */
const T_CATCH = UNKNOWN;
/**
 * @var int
 * @cvalue T_FINALLY
 */
const T_FINALLY = UNKNOWN;
/**
 * @var int
 * @cvalue T_THROW
 */
const T_THROW = UNKNOWN;
/**
 * @var int
 * @cvalue T_USE
 */
const T_USE = UNKNOWN;
/**
 * @var int
 * @cvalue T_INSTEADOF
 */
const T_INSTEADOF = UNKNOWN;
/**
 * @var int
 * @cvalue T_GLOBAL
 */
const T_GLOBAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_STATIC
 */
const T_STATIC = UNKNOWN;
/**
 * @var int
 * @cvalue T_ABSTRACT
 */
const T_ABSTRACT = UNKNOWN;
/**
 * @var int
 * @cvalue T_FINAL
 */
const T_FINAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_PRIVATE
 */
const T_PRIVATE = UNKNOWN;
/**
 * @var int
 * @cvalue T_PROTECTED
 */
const T_PROTECTED = UNKNOWN;
/**
 * @var int
 * @cvalue T_PUBLIC
 */
const T_PUBLIC = UNKNOWN;
/**
 * @var int
 * @cvalue T_PRIVATE_SET
 */
const T_PRIVATE_SET = UNKNOWN;
/**
 * @var int
 * @cvalue T_PROTECTED_SET
 */
const T_PROTECTED_SET = UNKNOWN;
/**
 * @var int
 * @cvalue T_PUBLIC_SET
 */
const T_PUBLIC_SET = UNKNOWN;
/**
 * @var int
 * @cvalue T_READONLY
 */
const T_READONLY = UNKNOWN;
/**
 * @var int
 * @cvalue T_VAR
 */
const T_VAR = UNKNOWN;
/**
 * @var int
 * @cvalue T_UNSET
 */
const T_UNSET = UNKNOWN;
/**
 * @var int
 * @cvalue T_ISSET
 */
const T_ISSET = UNKNOWN;
/**
 * @var int
 * @cvalue T_EMPTY
 */
const T_EMPTY = UNKNOWN;
/**
 * @var int
 * @cvalue T_HALT_COMPILER
 */
const T_HALT_COMPILER = UNKNOWN;
/**
 * @var int
 * @cvalue T_CLASS
 */
const T_CLASS = UNKNOWN;
/**
 * @var int
 * @cvalue T_TRAIT
 */
const T_TRAIT = UNKNOWN;
/**
 * @var int
 * @cvalue T_INTERFACE
 */
const T_INTERFACE = UNKNOWN;
/**
 * @var int
 * @cvalue T_ENUM
 */
const T_ENUM = UNKNOWN;
/**
 * @var int
 * @cvalue T_EXTENDS
 */
const T_EXTENDS = UNKNOWN;
/**
 * @var int
 * @cvalue T_IMPLEMENTS
 */
const T_IMPLEMENTS = UNKNOWN;
/**
 * @var int
 * @cvalue T_NAMESPACE
 */
const T_NAMESPACE = UNKNOWN;
/**
 * @var int
 * @cvalue T_LIST
 */
const T_LIST = UNKNOWN;
/**
 * @var int
 * @cvalue T_ARRAY
 */
const T_ARRAY = UNKNOWN;
/**
 * @var int
 * @cvalue T_CALLABLE
 */
const T_CALLABLE = UNKNOWN;
/**
 * @var int
 * @cvalue T_LINE
 */
const T_LINE = UNKNOWN;
/**
 * @var int
 * @cvalue T_FILE
 */
const T_FILE = UNKNOWN;
/**
 * @var int
 * @cvalue T_DIR
 */
const T_DIR = UNKNOWN;
/**
 * @var int
 * @cvalue T_CLASS_C
 */
const T_CLASS_C = UNKNOWN;
/**
 * @var int
 * @cvalue T_TRAIT_C
 */
const T_TRAIT_C = UNKNOWN;
/**
 * @var int
 * @cvalue T_METHOD_C
 */
const T_METHOD_C = UNKNOWN;
/**
 * @var int
 * @cvalue T_FUNC_C
 */
const T_FUNC_C = UNKNOWN;
/**
 * @var int
 * @cvalue T_PROPERTY_C
 */
const T_PROPERTY_C = UNKNOWN;
/**
 * @var int
 * @cvalue T_NS_C
 */
const T_NS_C = UNKNOWN;
/**
 * @var int
 * @cvalue T_ATTRIBUTE
 */
const T_ATTRIBUTE = UNKNOWN;
/**
 * @var int
 * @cvalue T_PLUS_EQUAL
 */
const T_PLUS_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_MINUS_EQUAL
 */
const T_MINUS_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_MUL_EQUAL
 */
const T_MUL_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_DIV_EQUAL
 */
const T_DIV_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_CONCAT_EQUAL
 */
const T_CONCAT_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_MOD_EQUAL
 */
const T_MOD_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_AND_EQUAL
 */
const T_AND_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_OR_EQUAL
 */
const T_OR_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_XOR_EQUAL
 */
const T_XOR_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_SL_EQUAL
 */
const T_SL_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_SR_EQUAL
 */
const T_SR_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_COALESCE_EQUAL
 */
const T_COALESCE_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_BOOLEAN_OR
 */
const T_BOOLEAN_OR = UNKNOWN;
/**
 * @var int
 * @cvalue T_BOOLEAN_AND
 */
const T_BOOLEAN_AND = UNKNOWN;
/**
 * @var int
 * @cvalue T_IS_EQUAL
 */
const T_IS_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_IS_NOT_EQUAL
 */
const T_IS_NOT_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_IS_IDENTICAL
 */
const T_IS_IDENTICAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_IS_NOT_IDENTICAL
 */
const T_IS_NOT_IDENTICAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_IS_SMALLER_OR_EQUAL
 */
const T_IS_SMALLER_OR_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_IS_GREATER_OR_EQUAL
 */
const T_IS_GREATER_OR_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_SPACESHIP
 */
const T_SPACESHIP = UNKNOWN;
/**
 * @var int
 * @cvalue T_SL
 */
const T_SL = UNKNOWN;
/**
 * @var int
 * @cvalue T_SR
 */
const T_SR = UNKNOWN;
/**
 * @var int
 * @cvalue T_INC
 */
const T_INC = UNKNOWN;
/**
 * @var int
 * @cvalue T_DEC
 */
const T_DEC = UNKNOWN;
/**
 * @var int
 * @cvalue T_INT_CAST
 */
const T_INT_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_DOUBLE_CAST
 */
const T_DOUBLE_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_STRING_CAST
 */
const T_STRING_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_ARRAY_CAST
 */
const T_ARRAY_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_OBJECT_CAST
 */
const T_OBJECT_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_BOOL_CAST
 */
const T_BOOL_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_UNSET_CAST
 */
const T_UNSET_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_VOID_CAST
 */
const T_VOID_CAST = UNKNOWN;
/**
 * @var int
 * @cvalue T_OBJECT_OPERATOR
 */
const T_OBJECT_OPERATOR = UNKNOWN;
/**
 * @var int
 * @cvalue T_NULLSAFE_OBJECT_OPERATOR
 */
const T_NULLSAFE_OBJECT_OPERATOR = UNKNOWN;
/**
 * @var int
 * @cvalue T_DOUBLE_ARROW
 */
const T_DOUBLE_ARROW = UNKNOWN;
/**
 * @var int
 * @cvalue T_COMMENT
 */
const T_COMMENT = UNKNOWN;
/**
 * @var int
 * @cvalue T_DOC_COMMENT
 */
const T_DOC_COMMENT = UNKNOWN;
/**
 * @var int
 * @cvalue T_OPEN_TAG
 */
const T_OPEN_TAG = UNKNOWN;
/**
 * @var int
 * @cvalue T_OPEN_TAG_WITH_ECHO
 */
const T_OPEN_TAG_WITH_ECHO = UNKNOWN;
/**
 * @var int
 * @cvalue T_CLOSE_TAG
 */
const T_CLOSE_TAG = UNKNOWN;
/**
 * @var int
 * @cvalue T_WHITESPACE
 */
const T_WHITESPACE = UNKNOWN;
/**
 * @var int
 * @cvalue T_START_HEREDOC
 */
const T_START_HEREDOC = UNKNOWN;
/**
 * @var int
 * @cvalue T_END_HEREDOC
 */
const T_END_HEREDOC = UNKNOWN;
/**
 * @var int
 * @cvalue T_DOLLAR_OPEN_CURLY_BRACES
 */
const T_DOLLAR_OPEN_CURLY_BRACES = UNKNOWN;
/**
 * @var int
 * @cvalue T_CURLY_OPEN
 */
const T_CURLY_OPEN = UNKNOWN;
/**
 * @var int
 * @cvalue T_PAAMAYIM_NEKUDOTAYIM
 */
const T_PAAMAYIM_NEKUDOTAYIM = UNKNOWN;
/**
 * @var int
 * @cvalue T_NS_SEPARATOR
 */
const T_NS_SEPARATOR = UNKNOWN;
/**
 * @var int
 * @cvalue T_ELLIPSIS
 */
const T_ELLIPSIS = UNKNOWN;
/**
 * @var int
 * @cvalue T_COALESCE
 */
const T_COALESCE = UNKNOWN;
/**
 * @var int
 * @cvalue T_POW
 */
const T_POW = UNKNOWN;
/**
 * @var int
 * @cvalue T_POW_EQUAL
 */
const T_POW_EQUAL = UNKNOWN;
/**
 * @var int
 * @cvalue T_PIPE
 */
const T_PIPE = UNKNOWN;
/**
 * @var int
 * @cvalue T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG
 */
const T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG = UNKNOWN;
/**
 * @var int
 * @cvalue T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG
 */
const T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG = UNKNOWN;
/**
 * @var int
 * @cvalue T_BAD_CHARACTER
 */
const T_BAD_CHARACTER = UNKNOWN;
/**
 * @var int
 * @cvalue T_PAAMAYIM_NEKUDOTAYIM
 */
const T_DOUBLE_COLON = UNKNOWN;
